@@ -25,6 +25,10 @@ except ImportError:
     pass
 
 
+def Dummy(*args, **kwargs):
+    pass
+
+
 class Annotation:
     """Annotation 结构"""
 
@@ -82,15 +86,16 @@ class Annotation:
         # 以下四个是 annotationlib 的 action 结构
         # SSA(Sub Station Alpha)(ASS)(Advanced SubStation Alpha) 不能实现交互,
         # 处理 action 没有意义
-        self.actionType: Literal["time", "url"] = "time"
-        self.actionUrl: str = ""
-        self.actionUrlTarget: str = ""
-        self.actionSeconds: datetime.datetime = datetime.datetime.strptime("0", "%S")
-        self.highlightId: str = ""
-        # 以下是按我喜好写的 action 结构, 作为补充
-        # 这俩是 actionValue 拆解后的结果
-        self.actionSourceVideoId: str = ""
-        self.actionTargetVideoId: str = ""
+        # self.actionType: Literal["time", "url"] = "time"
+        # self.actionUrl: str = ""
+        # self.actionUrlTarget: str = ""
+        # self.actionSeconds: datetime.datetime = datetime.datetime.strptime("0", "%S")
+        # self.highlightId: str = ""
+        # # 以下是按我喜好写的 action 结构, 作为补充
+        # # 这俩是 actionValue 拆解后的结果
+        # self.actionSourceVideoId: str = ""
+        # self.actionTargetVideoId: str = ""
+        self.author: str = ""
 
 
 def Parse(tree: Element) -> List[Annotation]:
@@ -231,16 +236,29 @@ def Parse(tree: Element) -> List[Annotation]:
                 Stderr(_("{} 不显示, 跳过").format(annotation.id))
             return None
 
-        # 其实这些字符串可以直接在 SSA 上用的, 但是不知道为什么之前来回转换了两次
-        # 那些代码已经是两年前写的了
-        # 我也忘了
-        try:
-            annotation.timeStart = datetime.datetime.strptime(Start, "%H:%M:%S.%f")
-            # 在这之前我会在这里 ↓ 加两个空格与上面对齐, 但是 black 好像不太喜欢
-            annotation.timeEnd = datetime.datetime.strptime(End, "%H:%M:%S.%f")
-        except:
-            annotation.timeStart = datetime.datetime.strptime(Start, "%M:%S.%f")
-            annotation.timeEnd = datetime.datetime.strptime(End, "%M:%S.%f")
+        # # 其实这些字符串可以直接在 SSA 上用的, 但是不知道为什么之前来回转换了两次
+        # # 那些代码已经是两年前写的了
+        # # 我也忘了
+        # try:
+        #     annotation.timeStart = datetime.datetime.strptime(Start, "%H:%M:%S.%f")
+        #     # 在这之前我会在这里 ↓ 加两个空格与上面对齐, 但是 black 好像不太喜欢
+        #     annotation.timeEnd = datetime.datetime.strptime(End, "%H:%M:%S.%f")
+        # except:
+        #     annotation.timeStart = datetime.datetime.strptime(Start, "%M:%S.%f")
+        #     annotation.timeEnd = datetime.datetime.strptime(End, "%M:%S.%f")
+
+        def ParseTime(timeString: str) -> datetime.datetime:
+            colon = timeString.count(":")
+            timeFormat = ""
+            if colon == 2:
+                timeFormat += "%H:"
+            timeFormat += "%M:%S"
+            if "." in timeString:
+                timeFormat += ".%f"
+            return datetime.datetime.strptime(timeString, timeFormat)
+
+        annotation.timeStart = ParseTime(Start)
+        annotation.timeEnd = ParseTime(End)
 
         annotation.x = float(MakeSureStr(Segment[0].get("x")))
         annotation.y = float(MakeSureStr(Segment[0].get("y")))
@@ -283,42 +301,47 @@ def Parse(tree: Element) -> List[Annotation]:
             if textSize != None:
                 annotation.textSize = float(MakeSureStr(textSize))
 
-        value = target = src_vid = v = ""
-        Action = each.find("action")
-        if Action != None:
-            Action = MakeSureElement(Action)
-            Url = Action.find("url")
-            if Url != None:
-                Url = MakeSureElement(Url)
-                value = MakeSureStr(Url.get("value"))
-                target = MakeSureStr(Url.get("target"))
-                if value.startswith("https://www.youtube.com/"):
-                    u = urllib.parse.urlparse(value)
-                    params = urllib.parse.parse_qs(u.query)
-                    src_vid = params["src_vid"][0]
-                    v = params["v"][0]
-                    _type = "url"
-                    if src_vid == v:
-                        fragment = u.fragment
-                        if fragment.startswith("t="):
-                            timeString = fragment.split("t=")[1]
-                            seconds = datetime.datetime.strptime(timeString, "%Ss")
-                            _type = "time"
-                            annotation.actionSeconds = seconds
-            annotation.actionType = _type  # type: ignore
-            annotation.actionUrl = MakeSureStr(value)
-            annotation.actionUrlTarget = MakeSureStr(target)
-            annotation.actionSourceVideoId = src_vid
-            annotation.actionTargetVideoId = v
+        author = each.get("author")
+        if author != None:
+            annotation.author = MakeSureStr(each.get("author"))
 
-        Trigger = each.find("trigger")
-        if Trigger != None:
-            Trigger = MakeSureElement(Trigger)
-            Condition = MakeSureElement(Trigger.find("condition"))
-            annotation.highlightId = MakeSureStr(Condition.get("ref"))
+        # value = target = src_vid = v = ""
+        # Action = each.find("action")
+        # if Action != None:
+        #     Action = MakeSureElement(Action)
+        #     Url = Action.find("url")
+        #     if Url != None:
+        #         Url = MakeSureElement(Url)
+        #         value = MakeSureStr(Url.get("value"))
+        #         target = MakeSureStr(Url.get("target"))
+        #         if value.startswith("https://www.youtube.com/"):
+        #             u = urllib.parse.urlparse(value)
+        #             params = urllib.parse.parse_qs(u.query)
+        #             src_vid = params["src_vid"][0]
+        #             v = params["v"][0]
+        #             _type = "url"
+        #             if src_vid == v:
+        #                 fragment = u.fragment
+        #                 if fragment.startswith("t="):
+        #                     timeString = fragment.split("t=")[1]
+        #                     seconds = datetime.datetime.strptime(timeString, "%Ss")
+        #                     _type = "time"
+        #                     annotation.actionSeconds = seconds
+        #     annotation.actionType = _type  # type: ignore
+        #     annotation.actionUrl = MakeSureStr(value)
+        #     annotation.actionUrlTarget = MakeSureStr(target)
+        #     annotation.actionSourceVideoId = src_vid
+        #     annotation.actionTargetVideoId = v
+
+        # Trigger = each.find("trigger")
+        # if Trigger != None:
+        #     Trigger = MakeSureElement(Trigger)
+        #     Condition = MakeSureElement(Trigger.find("condition"))
+        #     annotation.highlightId = MakeSureStr(Condition.get("ref"))
 
         return annotation
 
+    Dummy([ParseAnnotationAlpha, ParseAnnotationColor, MakeSureElement])
     annotations: List[Annotation] = []
     # 下面这行代码先从 youtube-ass 传到之前的 Annotations2Sub, 再从之前的 Annotations2Sub 传到这里
     for each in tree.find("annotations").findall("annotation"):  # type: ignore
