@@ -235,6 +235,14 @@ def Convert(
 
             return Box(event)
 
+        def label_text(event: Event) -> Event:
+            event.Name += ";label;text"
+            return Text(event)
+
+        def label_box(event: Event) -> Event:
+            event.Name += ";label;box"
+            return Box(event)
+
         events: List[Event] = []
         event = Event()
 
@@ -244,7 +252,10 @@ def Convert(
         event.End = each.timeEnd
         # Name 置为 "id" 主要为了方便调试, 其次才是辨识
         # 随便一提, Name 在 Aegisub 里是 "说话人"
-        event.Name = each.id
+        if each.author:
+            event.Name += each.author
+            event.Name += ";"
+        event.Name += each.id
 
         text = each.text
         # SSA 用 "\N" 换行
@@ -308,6 +319,9 @@ def Convert(
         elif each.style == "anchored":
             events.append(anchored_text(copy.copy(event)))
             events.append(anchored_box(copy.copy(event)))
+        elif each.style == "label":
+            events.append(label_text(copy.copy(event)))
+            events.append(label_box(copy.copy(event)))
         else:
             # 传承于 Annotations2Sub™
             Stderr(_("不支持 {} 样式 ({})").format(each.style, each.id))
