@@ -7,16 +7,19 @@ import datetime
 from typing import Dict, List
 
 from Annotations2Sub.Color import Alpha, Color, Rgba
-from Annotations2Sub.tools import _
+from Annotations2Sub.utils import _
 
 # 兼容 Python3.6, 3.7
 # Python3.6, 3.7 的 typing 没有 Literal
 try:
     from typing import Literal  # type: ignore
 except ImportError:
-    from Annotations2Sub.tools import DummyLiteral
 
-    exec("Literal = DummyLiteral()")
+    class a:
+        def __getitem__(self, b):
+            return b
+
+    exec("Literal = a()")
 
 
 class Style:
@@ -125,7 +128,7 @@ class Sub:
             for i in self.note:
                 s += "; " + i + "\n"
             for k, v in self.info.items():
-                s += "{}: {}\n".format(k, v)
+                s += f"{k}: {v}\n"
             s += "\n"
             return s
 
@@ -251,5 +254,5 @@ class Draw:
         # 建议下一个 Aegisub 然后打开 ASSDraw3 画画玩玩
         s = ""
         for i in self.draw:
-            s = s + "{} {} {} ".format(i.command, i.x, i.y)
+            s = s + f"{i.command} {i.x} {i.y} "
         return s
