@@ -1,8 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
+import sys
+
 from Annotations2Sub.cli import run
 
 
 def main():
-    run()
+    sys.exit(run())
