@@ -3,13 +3,13 @@
 
 import gettext
 import os
-import sys
 
 import pytest
 
 from Annotations2Sub.utils import MakeSureStr, RedText, YellowText, internationalization
 
-sys.path.append(os.path.dirname(os.path.abspath(__file__)))
+basePath = os.path.dirname(__file__)
+file1 = os.path.join(basePath, "test", "1.test")
 
 
 def test_YellowText():
@@ -30,10 +30,10 @@ def test_internationalization():
 
 
 def test_internationalization2():
-    def a(*args, **kwargs):
-        raise Exception
+    def f(*args, **kwargs):
+        raise FileNotFoundError
 
     m = pytest.MonkeyPatch()
-    m.setattr(gettext, "translation", a)
+    m.setattr(gettext, "translation", f)
 
     internationalization()
